#!/bin/bash

echo -e "XXXXXXX\tF/C=C/F\tF/C=C\\F" \
    | smi_isomorphism
